@@ -236,6 +236,9 @@ def _chunk(dataset: xr.Dataset, *, ideal_chunk_size_mb: float) -> xr.Dataset:
     # Number of floats in a megabyte (assuming 64 bit floats).
     num_float_in_mb = 1024 * 1024 / 8
 
+    # becasue of compressions we can make this number larger
+    num_float_in_mb = num_float_in_mb * 5
+
     # Calculate the `size` do we need for x and y if we want to have chunks of
     # `ideal_chunk_size_mb` megabytes.
     size = int(math.sqrt(ideal_chunk_size_mb * num_float_in_mb / num_step / num_variables))
